summaryrefslogtreecommitdiff
path: root/src/debug
diff options
context:
space:
mode:
authorあまみや ゆうこ <1@1234.sh>2015-10-07 07:00:15 +0800
committerあまみや ゆうこ <1@1234.sh>2015-10-07 07:00:15 +0800
commit1f940efbe82d6ba5a9c7f8269f087d0709d77011 (patch)
tree15c32f2a8a5a53d34afef901f827c960da885dbb /src/debug
parentef9e505c66a82dc6928b8ddf9332a88e675d532d (diff)
downloadcoreclr-1f940efbe82d6ba5a9c7f8269f087d0709d77011.tar.gz
coreclr-1f940efbe82d6ba5a9c7f8269f087d0709d77011.tar.bz2
coreclr-1f940efbe82d6ba5a9c7f8269f087d0709d77011.zip
correct word spelling
Diffstat (limited to 'src/debug')
-rw-r--r--src/debug/di/process.cpp20
-rw-r--r--src/debug/di/shimevents.cpp2
-rw-r--r--src/debug/ee/controller.cpp2
-rw-r--r--src/debug/ee/debugger.cpp2
-rw-r--r--src/debug/ee/funceval.cpp6
-rw-r--r--src/debug/inc/dbgtransportsession.h2
6 files changed, 17 insertions, 17 deletions
diff --git a/src/debug/di/shimevents.cpp b/src/debug/di/shimevents.cpp
index 2a1430176e..a381218ae5 100644
--- a/src/debug/di/shimevents.cpp
+++ b/src/debug/di/shimevents.cpp
@@ -78,7 +78,7 @@ ICorDebugManagedCallback3 * ManagedEvent::DispatchArgs::GetCallback3()
return m_pCallback3;
}
-// Returns OS Thread Id that this event occured on, 0 if no thread affinity.
+// Returns OS Thread Id that this event occurred on, 0 if no thread affinity.
DWORD ManagedEvent::GetOSTid()
{
return m_dwThreadId;
diff --git a/src/debug/ee/controller.cpp b/src/debug/ee/controller.cpp
index 9a990dec81..9988378c7a 100644
--- a/src/debug/ee/controller.cpp
+++ b/src/debug/ee/controller.cpp
@@ -2775,7 +2775,7 @@ DebuggerControllerPatch *DebuggerController::GetEnCPatch(const BYTE *address)
#endif //EnC_SUPPORTED
// DebuggerController::DispatchPatchOrSingleStep - Ask any patches that are active at a given
-// address if they want to do anything about the exception that's occured there. How: For the given
+// address if they want to do anything about the exception that's occurred there. How: For the given
// address, go through the list of patches & see if any of them are interested (by invoking their
// DebuggerController's TriggerPatch). Put any DCs that are interested into a queue and then calls
// SendEvent on each.
diff --git a/src/debug/ee/debugger.cpp b/src/debug/ee/debugger.cpp
index 270615bc1e..41359b8d80 100644
--- a/src/debug/ee/debugger.cpp
+++ b/src/debug/ee/debugger.cpp
@@ -7714,7 +7714,7 @@ HRESULT Debugger::SendException(Thread *pThread,
if (fAttaching)
{
JitAttach(pThread, pExceptionInfo, managedEventNeeded, FALSE);
- // If the jit-attach occured, CORDebuggerAttached() may now be true and we can
+ // If the jit-attach occurred, CORDebuggerAttached() may now be true and we can
// just act as if a debugger was always attached.
}
diff --git a/src/debug/ee/funceval.cpp b/src/debug/ee/funceval.cpp
index 40e22aff5f..c7ec48d20c 100644
--- a/src/debug/ee/funceval.cpp
+++ b/src/debug/ee/funceval.cpp
@@ -2961,7 +2961,7 @@ void FuncEvalWrapper(MethodDescCallSite* pMDCS, DebuggerEval *pDE, ARG_SLOT *pAr
/*
* RecordFuncEvalException
*
- * Helper function records the details of an exception that occured during a FuncEval
+ * Helper function records the details of an exception that occurred during a FuncEval
* Note that this should be called from within the target domain of the FuncEval.
*
* Parameters:
@@ -3486,7 +3486,7 @@ static void GCProtectArgsAndDoNormalFuncEval(DebuggerEval *pDE,
RecordFuncEvalException( pDE, ppException);
}
// Note: we need to catch all exceptioins here because they all get reported as the result of
- // the funceval. If a ThreadAbort occured other than for a funcEval abort, we'll re-throw it manually.
+ // the funceval. If a ThreadAbort occurred other than for a funcEval abort, we'll re-throw it manually.
EX_END_CATCH(SwallowAllExceptions);
// Restore context
@@ -3692,7 +3692,7 @@ void FuncEvalHijackRealWorker(DebuggerEval *pDE, Thread* pThread, FuncEvalFrame*
RecordFuncEvalException( pDE, ppException);
}
// Note: we need to catch all exceptioins here because they all get reported as the result of
- // the funceval. If a ThreadAbort occured other than for a funcEval abort, we'll re-throw it manually.
+ // the funceval. If a ThreadAbort occurred other than for a funcEval abort, we'll re-throw it manually.
EX_END_CATCH(SwallowAllExceptions);
GCPROTECT_END();
diff --git a/src/debug/inc/dbgtransportsession.h b/src/debug/inc/dbgtransportsession.h
index 4f844ba984..6464646f1f 100644
--- a/src/debug/inc/dbgtransportsession.h
+++ b/src/debug/inc/dbgtransportsession.h
@@ -397,7 +397,7 @@ private:
SS_Opening_NC, // Session is being formed but no connection is established yet
SS_Opening, // Session is being formed, the low level connection is in place
SS_Open, // Session is fully formed and normal transport messages can be sent and received
- SS_Resync_NC, // A low level connection error is occured and we're attempting to re-form the link
+ SS_Resync_NC, // A low level connection error is occurred and we're attempting to re-form the link
SS_Resync, // We're trying to resynchronize high level state over the new connection
};
diff --git a/src/debug/di/process.cpp b/src/debug/di/process.cpp
index 484905b62b..8b148612b8 100644
--- a/src/debug/di/process.cpp
+++ b/src/debug/di/process.cpp
@@ -4700,7 +4700,7 @@ void CordbProcess::DispatchRCEvent()
}
HRESULT hrCallback = S_OK;
// It's possible a ICorDebugProcess::Detach() may have occured by now.
{
// @dbgtodo shim: eventually the entire RCET should be considered outside the RS.
PUBLIC_CALLBACK_IN_THIS_SCOPE0_NO_LOCK(this);
@@ -4999,7 +4999,7 @@ void CordbProcess::RawDispatchEvent(
_ASSERTE(pAppDomain != NULL);
// For some exceptions very early in startup (eg, TypeLoad), this may have occured before we
// even executed jitted code on the thread. We may have not received a CreateThread yet.
// In V2, we detected this and sent a LogMessage on a random thread.
// In V3, we lazily create the CordbThread objects (possibly before the CreateThread event),
@@ -11305,7 +11305,7 @@ HRESULT CordbProcess::SetEnableCustomNotification(ICorDebugClass * pClass, BOOL
// countBytes - number of bytes in pRawRecord buffer.
// format - format of pRawRecord
// dwFlags - flags providing auxillary info for exception record.
// dwThreadId - thread that exception occured on.
// pCallback - callback to dispatch potential managed events on.
// pContinueStatus - Continuation status for exception. This dictates what
// to pass to kernel32!ContinueDebugEvent().
@@ -12235,8 +12235,8 @@ Reaction CordbProcess::Triage1stChanceNonSpecial(CordbUnmanagedThread * pUnmanag
// Triage a 1st-chance exception when the CLR is initialized.
//
// Arguments:
// pUnmanagedThread - thread that the event has occured on.
// pEvent - native debug event for the exception that occured that this is triaging.
//
// Return Value:
// Reaction for how to handle this event.
@@ -12534,8 +12534,8 @@ Reaction CordbProcess::TriageExcep1stChanceAndInit(CordbUnmanagedThread * pUnman
// Triage a 2nd-chance exception when the CLR is initialized.
//
// Arguments:
// pUnmanagedThread - thread that the event has occured on.
// pEvent - native debug event for the exception that occured that this is triaging.
//
// Return Value:
// Reaction for how to handle this event.
@@ -12568,7 +12568,7 @@ Reaction CordbProcess::TriageExcep2ndChanceAndInit(CordbUnmanagedThread * pUnman
if (dwNo2ndChance)
{
- CONSISTENCY_CHECK_MSGF(false, ("2nd chance exception occured on LS thread=0x%x, code=0x%08x, address=0x%p\n"
+ CONSISTENCY_CHECK_MSGF(false, ("2nd chance exception occurred on LS thread=0x%x, code=0x%08x, address=0x%p\n"
"This assert is firing b/c you explicitly requested it by having the 'DbgNo2ndChance' knob enabled.\n"
"Disable it to avoid asserts on 2nd chance.",
pUnmanagedThread->m_id,
@@ -12621,8 +12621,8 @@ Reaction CordbProcess::TriageExcep2ndChanceAndInit(CordbUnmanagedThread * pUnman
// Triage a win32 Debug event to get a reaction
//
// Arguments:
// pUnmanagedThread - thread that the event has occured on.
// pEvent - native debug event for the exception that occured that this is triaging.
//
// Return Value:
// Reaction for how to handle this event.
@@ -4700,7 +4700,7 @@ void CordbProcess::DispatchRCEvent()
}
HRESULT hrCallback = S_OK;
- // It's possible a ICorDebugProcess::Detach() may have occured by now.
+ // It's possible a ICorDebugProcess::Detach() may have occurred by now.
{
// @dbgtodo shim: eventually the entire RCET should be considered outside the RS.
@@ -4999,7 +4999,7 @@ void CordbProcess::RawDispatchEvent(
_ASSERTE(pAppDomain != NULL);
- // For some exceptions very early in startup (eg, TypeLoad), this may have occured before we
+ // For some exceptions very early in startup (eg, TypeLoad), this may have occurred before we
// even executed jitted code on the thread. We may have not received a CreateThread yet.
// In V2, we detected this and sent a LogMessage on a random thread.
@@ -11305,7 +11305,7 @@ HRESULT CordbProcess::SetEnableCustomNotification(ICorDebugClass * pClass, BOOL
// format - format of pRawRecord
// dwFlags - flags providing auxillary info for exception record.
-// dwThreadId - thread that exception occured on.
+// dwThreadId - thread that exception occurred on.
// pCallback - callback to dispatch potential managed events on.
// pContinueStatus - Continuation status for exception. This dictates what
@@ -12235,8 +12235,8 @@ Reaction CordbProcess::Triage1stChanceNonSpecial(CordbUnmanagedThread * pUnmanag
//
// Arguments:
-// pUnmanagedThread - thread that the event has occured on.
-// pEvent - native debug event for the exception that occured that this is triaging.
+// pUnmanagedThread - thread that the event has occurred on.
+// pEvent - native debug event for the exception that occurred that this is triaging.
//
// Return Value:
@@ -12534,8 +12534,8 @@ Reaction CordbProcess::TriageExcep1stChanceAndInit(CordbUnmanagedThread * pUnman
//
// Arguments:
-// pUnmanagedThread - thread that the event has occured on.
-// pEvent - native debug event for the exception that occured that this is triaging.
+// pUnmanagedThread - thread that the event has occurred on.
+// pEvent - native debug event for the exception that occurred that this is triaging.
//
// Return Value:
@@ -12621,8 +12621,8 @@ Reaction CordbProcess::TriageExcep2ndChanceAndInit(CordbUnmanagedThread * pUnman
//
// Arguments:
-// pUnmanagedThread - thread that the event has occured on.
-// pEvent - native debug event for the exception that occured that this is triaging.
+// pUnmanagedThread - thread that the event has occurred on.
+// pEvent - native debug event for the exception that occurred that this is triaging.
//
// Return Value: